@@ -1,7 +1,7 @@
 # frozen_string_literal: true
 
 # Released under the MIT License.
-# Copyright, 2022, by Samuel Williams.
+# Copyright, 2022-2023, by Samuel Williams.
 
 require 'rack'
 
@@ -11,7 +11,7 @@ require_relative 'adapter/rack3'
 module Protocol
 	module Rack
 		module Adapter
-			if ::Rack::RELEASE >= "3"
+			if ::Rack.release >= "3"
 				IMPLEMENTATION = Rack3
 			else
 				IMPLEMENTATION = Rack2
